@@ -12,6 +12,7 @@
 #include "buffer.h"
 #include "bytecode.h"
 #include "stack.h"
+#include "config.h"
 
 struct rl_cleanup {
 	int type;
@@ -21,7 +22,7 @@ struct rl_cleanup {
 
 struct rl_instance {
 	struct sockaddr *sin;
-	int sinlen;
+	socklen_t sinlen;
 	struct rusage rusage;
 	int status;
 	time_t start;
